cellsino
========

|PyPI Version| |Tests Status| |Coverage Status| |Docs Status|


**Cellsino** is a Python library for generating sinograms (phase and
fluorescence) of cell phantoms for testing tomographic reconstruction algorithms.


Documentation
-------------

The documentation, including the code reference and examples, is available at
`cellsino.readthedocs.io <https://cellsino.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install cellsino


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |PyPI Version| image:: https://img.shields.io/pypi/v/cellsino.svg
   :target: https://pypi.python.org/pypi/cellsino
.. |Tests Status| image:: https://img.shields.io/travis/RI-imaging/cellsino.svg
   :target: https://travis-ci.org/RI-imaging/cellsino
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/RI-imaging/cellsino/master.svg
   :target: https://codecov.io/gh/RI-imaging/cellsino
.. |Docs Status| image:: https://readthedocs.org/projects/cellsino/badge/?version=latest
   :target: https://readthedocs.org/projects/cellsino/builds/

